==> nextcloud-12.0.4.tar.bz2: nextcloud/apps/dav/l10n/el.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Ημερολόγιο",
    "Todos" : "Εργασίες προς εκτέλεση",
    "Personal" : "Προσωπικά",
    "{actor} created calendar {calendar}" : "{actor} δημιουργήθηκε το ημερολόγιο {calendar}",
    "You created calendar {calendar}" : "Δημιουργήσατε ημερολόγιο {ημερολόγιο}",
    "{actor} deleted calendar {calendar}" : "{actor} διέγραψε το ημερολόγιο {calendar}",
    "You deleted calendar {calendar}" : "Διαγράψατε το ημερολόγιο {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} ενημέρωσε το ημερολόγιο {calendar}",
    "You updated calendar {calendar}" : "Έχετε ενημερώσει το ημερολόγιο {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} διαμοιράστηκε το ημερολόγιο {calendar} με εσάς",
    "You shared calendar {calendar} with {user}" : "Διαμοιραστήκατε το ημερολογίου {calendar} με {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} διαμοίρασε το ημερολόγιο {calendar} με {user}",
    "{actor} unshared calendar {calendar} from you" : "Ο {actor} σταμάτησε τον διαμοιρασμό του ημερολογίου  {calendar} από εσάς",
    "You unshared calendar {calendar} from {user}" : "Σταματήσατε τον διαμοιρασμό ημερολογίου  {calendar} από {user}",
    "{actor} unshared calendar {calendar} from {user}" : "Ο {actor} σταμάτησε τον διαμοιρασμό του ημερολογίου  {calendar} από τον χρήστη {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} σταμάτησε το διαμοιρασμένο ημερολόγιο {calendar} από τον εαυτό τους",
    "You shared calendar {calendar} with group {group}" : "Διαμοιραστείκατε ένα ημερολόγιο {calendar} με την ομάδα {group}",
    "{actor} shared calendar {calendar} with group {group}" : "Ο {actor} διαμοιράστηκε το ημερολόγιο {calendar} με την ομάδα {group}",
    "You unshared calendar {calendar} from group {group}" : "Σταματήσατε τον διαμοιρασμό του ημερολογίου {calendar} από την ομάδα {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} σταμάτησε το διαμοιρασμένο ημερολόγιο {calendar} από την ομάδα {group}",
    "{actor} created event {event} in calendar {calendar}" : "Ο {actor} δημιούργησε το γεγονός {event} στο ημερολόγιο {calendar}",
    "You created event {event} in calendar {calendar}" : "Δημιουργήσατε το γεγονός {event} στο ημερολόγιο {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "Ο {actor} διέγραψε το γεγονός {event} από το ημερολόγιο {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Διαγράψατε το συμβάν {event} από το ημερολόγιο {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "Ο {actor} ενημέρωσε το γεγονός {event} στο ημερολόγιο {calendar}",
    "You updated event {event} in calendar {calendar}" : "Ενημερώσατε το συμβάν {event} στο ημερολόγιο {calendar}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} δημιούργησε την εκκρεμότητα {todo} στη λίστα {ημερολόγιο}",
    "You created todo {todo} in list {calendar}" : "Δημιουργήσατε την εκκρεμότητα {todo} στη λίστα {ημερολόγιο}",
    "{actor} deleted todo {todo} from list {calendar}" : "Ο {actor} διέγραψε την εκκρεμότητα  {todo} από τη  λίστα {ημερολόγιο}",
    "You deleted todo {todo} from list {calendar}" : "Διέγραψες την εκκρεμότητα {todo} από τη λίστα {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} ενημέρωσε την εκκρεμότητα {todo} στη λίστα {calendar}",
    "You updated todo {todo} in list {calendar}" : "Ενημέρωσες την εκκρεμότητα {todo} στη λίστα {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} επίλυσε την εκκρεμότητα {todo} στην λίστα {calendar}",
    "You solved todo {todo} in list {calendar}" : "Επίλυσες την εκκρεμότητα {todo} στην λίστα {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} άνοιξε ξανά την εκκρεμότητα {todo} στην λίστα {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Άνοιξες ξανά την εκκρεμότητα {todo} στην λίστα {calendar}",
    "A <strong>calendar</strong> was modified" : "Τροποποιήθηκε ένα <strong>ημερολόγιο</strong> ",
    "A calendar <strong>event</strong> was modified" : "Τροποποιήθηκε ένα <strong>γεγονός</strong> του ημερολογίου",
    "A calendar <strong>todo</strong> was modified" : "Ενός ημερολογίου η <strong>εκκρεμότητα</strong> τροποποιήθηκε",
    "Contact birthdays" : "Γενέθλια επαφών",
    "Contacts" : "Επαφές",
    "Technical details" : "Τεχνικές λεπτομέρειες",
    "Remote Address: %s" : "Απομακρυσμένη Διεύθυνση: %s",
    "Request ID: %s" : "ID Αιτήματος: %s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.11.tar.bz2: nextcloud/apps/dav/l10n/el.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Ημερολόγιο",
    "Todos" : "Εργασίες προς εκτέλεση",
    "Personal" : "Προσωπικά",
    "{actor} created calendar {calendar}" : "{actor} δημιουργήθηκε το ημερολόγιο {calendar}",
    "You created calendar {calendar}" : "Δημιουργήσατε ημερολόγιο {ημερολόγιο}",
    "{actor} deleted calendar {calendar}" : "{actor} διέγραψε το ημερολόγιο {calendar}",
    "You deleted calendar {calendar}" : "Διαγράψατε το ημερολόγιο {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} ενημέρωσε το ημερολόγιο {calendar}",
    "You updated calendar {calendar}" : "Έχετε ενημερώσει το ημερολόγιο {calendar}",
    "You shared calendar {calendar} as public link" : "Μοιραστήκατε το ημερολόγιο {calendar} με δημόσιο σύνδεσμο.",
    "You removed public link for calendar {calendar}" : "Αφαιρέσατε τον δημόσιο σύνδεσμο για το ημερολόγιο {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} διαμοιράστηκε το ημερολόγιο {calendar} με εσάς",
    "You shared calendar {calendar} with {user}" : "Διαμοιραστήκατε το ημερολογίου {calendar} με {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} διαμοίρασε το ημερολόγιο {calendar} με {user}",
    "{actor} unshared calendar {calendar} from you" : "Ο {actor} σταμάτησε τον διαμοιρασμό του ημερολογίου  {calendar} από εσάς",
    "You unshared calendar {calendar} from {user}" : "Σταματήσατε τον διαμοιρασμό ημερολογίου  {calendar} από {user}",
    "{actor} unshared calendar {calendar} from {user}" : "Ο {actor} σταμάτησε τον διαμοιρασμό του ημερολογίου  {calendar} από τον χρήστη {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} σταμάτησε το διαμοιρασμένο ημερολόγιο {calendar} από τον εαυτό τους",
    "You shared calendar {calendar} with group {group}" : "Διαμοιραστείκατε ένα ημερολόγιο {calendar} με την ομάδα {group}",
    "{actor} shared calendar {calendar} with group {group}" : "Ο {actor} διαμοιράστηκε το ημερολόγιο {calendar} με την ομάδα {group}",
    "You unshared calendar {calendar} from group {group}" : "Σταματήσατε τον διαμοιρασμό του ημερολογίου {calendar} από την ομάδα {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} σταμάτησε το διαμοιρασμένο ημερολόγιο {calendar} από την ομάδα {group}",
    "{actor} created event {event} in calendar {calendar}" : "Ο {actor} δημιούργησε το γεγονός {event} στο ημερολόγιο {calendar}",
    "You created event {event} in calendar {calendar}" : "Δημιουργήσατε το γεγονός {event} στο ημερολόγιο {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "Ο {actor} διέγραψε το γεγονός {event} από το ημερολόγιο {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Διαγράψατε το συμβάν {event} από το ημερολόγιο {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "Ο {actor} ενημέρωσε το γεγονός {event} στο ημερολόγιο {calendar}",
    "You updated event {event} in calendar {calendar}" : "Ενημερώσατε το συμβάν {event} στο ημερολόγιο {calendar}",
    "Busy" : "Απασχολημένος",
    "{actor} created todo {todo} in list {calendar}" : "{actor} δημιούργησε την εκκρεμότητα {todo} στη λίστα {ημερολόγιο}",
    "You created todo {todo} in list {calendar}" : "Δημιουργήσατε την εκκρεμότητα {todo} στη λίστα {ημερολόγιο}",
    "{actor} deleted todo {todo} from list {calendar}" : "Ο {actor} διέγραψε την εκκρεμότητα  {todo} από τη  λίστα {ημερολόγιο}",
    "You deleted todo {todo} from list {calendar}" : "Διέγραψες την εκκρεμότητα {todo} από τη λίστα {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} ενημέρωσε την εκκρεμότητα {todo} στη λίστα {calendar}",
    "You updated todo {todo} in list {calendar}" : "Ενημέρωσες την εκκρεμότητα {todo} στη λίστα {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} επίλυσε την εκκρεμότητα {todo} στην λίστα {calendar}",
    "You solved todo {todo} in list {calendar}" : "Επίλυσες την εκκρεμότητα {todo} στην λίστα {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} άνοιξε ξανά την εκκρεμότητα {todo} στην λίστα {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Άνοιξες ξανά την εκκρεμότητα {todo} στην λίστα {calendar}",
    "A <strong>calendar</strong> was modified" : "Τροποποιήθηκε ένα <strong>ημερολόγιο</strong> ",
    "A calendar <strong>event</strong> was modified" : "Τροποποιήθηκε ένα <strong>γεγονός</strong> του ημερολογίου",
    "A calendar <strong>todo</strong> was modified" : "Ενός ημερολογίου η <strong>εκκρεμότητα</strong> τροποποιήθηκε",
    "Contact birthdays" : "Γενέθλια επαφών",
    "%1$s via %2$s" : "%1$s μέσω %2$s",
    "Invitation canceled" : "Η πρόσκληση ακυρώθηκε.",
    "Hello %s," : "Γεια σου %s,",
    "The meeting »%1$s« with %2$s was canceled." : "Το meeting »%1$s« με τον/την %2$s ακυρώθηκε.",
    "Invitation updated" : "Ενημερώθηκε η πρόσκληση.",
    "The meeting »%1$s« with %2$s was updated." : "Το meeting » %1$s« με τον/την %2$s ενημερώθηκε.",
    "%1$s invited you to »%2$s«" : "Ο %1$s σας προσκάλεσε στο »%2$s«",
    "When:" : "Πότε:",
    "Where:" : "Που:",
    "Description:" : "Περιγραφή:",
    "Link:" : "Σύνδεσμος:",
    "Accept" : "Αποδοχή",
    "Decline" : "Απόρριψη",
    "More options …" : "Περισσότερες επιλογές...",
    "More options at %s" : "Περισσότερες επιλογές στο %s",
    "Contacts" : "Επαφές",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "Τερματικό WebDAV",
    "Technical details" : "Τεχνικές λεπτομέρειες",
    "Remote Address: %s" : "Απομακρυσμένη Διεύθυνση: %s",
    "Request ID: %s" : "ID Αιτήματος: %s",
    "Please contact the organizer directly." : "Παρακαλώ επικοινωνήστε απ' ευθείας με τον διοργανωτή.",
    "Are you accepting the invitation?" : "Αποδέχεστε την πρόσκληση;",
    "Save" : "Αποθήκευση",
    "Send invitations to attendees" : "Αποστολή προσκλήσεων στους συμμετέχοντες.",
    "Automatically generate a birthday calendar" : "Δημιουργία ημερολογίου γενεθλίων αυτόματα",
    "Birthday calendars will be generated by a background job." : "Τα ημερολόγια γενεθλίων θα δημιουργηθούν από μία εργασία παρασκηνίου.",
    "%s via %s" : "%s μέσω %s",
    "The meeting »%s« with %s was canceled." : "Το meeting »%s« με τον/την %s ακυρώθηκε.",
    "The meeting »%s« with %s was updated." : "Το meeting » %s « με τον/την %s ενημερώθηκε.",
    "%s invited you to »%s«" : "Ο %s σας προσκάλεσε στο  »%s«",
    "Please make sure to properly set up the email settings above." : "Παρακαλούμε σιγουρευθείτε οτι θα ενημερώσετε τις ρυθμίσεις email, παραπάνω."
},
"nplurals=2; plural=(n != 1);");
